#!/usr/bin/env python3

import argparse
import csv
import sys


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Process UEFI CSV output.")
    parser.add_argument(
        "csv_file", metavar="INPUT", type=argparse.FileType("r"), help="input CSV file"
    )
    parser.add_argument(
        "output_file", metavar="OUTPUT", type=argparse.FileType("w"), help="output file"
    )

    args = parser.parse_args()
    output_lines = []

    reader = csv.DictReader(args.csv_file)
    for row in reader:
        if len(row) != 3:
            print(f"Invalid line: {row}", file=sys.stderr)
            continue
        pnp_id = row["PNP ID"].strip()
        company_name = row["Company"].strip()
        if len(pnp_id) != 3:
            print(f"PNP ID: {pnp_id}", file=sys.stderr)
            continue
        if f"{pnp_id}\t{company_name}\n" not in output_lines:
            output_lines.append(f"{pnp_id}\t{company_name}\n")

    output_lines.sort(key=str.lower)

    for line in output_lines:
        args.output_file.write(line)



#!/usr/bin/env python

import re
import sys

# Check that the sorting order is preserved in pci.ids

vendor_id = None
device_id = None
lineno    = 1

file = open("pci.ids")
hexnum = '([0-9a-fA-F]{4})'
desc = '(.*\\S)'

for line in file:

    m = re.match(hexnum + '\\s+' + desc, line)
    if m:
        new_id = int('0x' + m.group (1), 16)
        if vendor_id is not None and new_id <= vendor_id:
            print ("%d: Vendor ID (0x%04x) is less that previous ID (0x%04x)" %
                   (lineno, new_id, vendor_id))
            sys.exit (-1)

        vendor_id = new_id
        device_id = -1

    m = re.match('\t' + hexnum + '\\s+' + desc, line)
    if m:
        new_id = int('0x' + m.group (1), 16)
        if new_id <= device_id:
            print ("%d: Device ID (0x%04x) is less that previous ID (0x%04x)" %
                   (lineno, new_id, device_id))
            sys.exit (-1)

        device_id = new_id

    lineno = lineno + 1
